import { Component, OnInit, ViewChild } from '@angular/core';
import {
  DayService,
  WeekService,
  WorkWeekService,
  MonthService,
  AgendaService,
  ResizeService,
  DragAndDropService,
  EventSettingsModel,
  ScheduleComponent,
  View,
  EventRenderedArgs,
  PopupOpenEventArgs,
  PopupCloseEventArgs,
  ActionEventArgs,
  CurrentAction
} from '@syncfusion/ej2-angular-schedule';
import { extend, L10n, loadCldr, Internationalization, removeClass } from '@syncfusion/ej2-base';
import { Subject, Subscription } from 'rxjs';
import { debounceTime, distinctUntilChanged, map } from 'rxjs/operators';
import { ElasticsearchService } from 'app/shared/services/elasticsearch.service';
import { Betrieb } from 'app/shared/models/betrieb.model';
import { GescheftbDTO, GsbadresseDTOList, GsbkomunikationDTOList } from 'app/shared/models/gescheftbDTO.model';
import { Actioncode, ListeTerminZustand } from 'app/shared/enum/enum.model';
import { Bp } from 'app/shared/models/bp.model';
import { Liland } from 'app/shared/models/liland.model';
import { sortSuggestion } from 'app/shared/util/sort-util';
import { rechform } from 'app/shared/models/rechtform.model';
import { AccountService } from 'app/core/auth/account.service';
import { BpService } from 'app/shared/services/bp.service';
import { RechtformService } from 'app/shared/services/rechtform.service';
import { LilandService_bp } from 'app/shared/services/liland-bp.service';
import { DashboardModel } from 'app/shared/models/dashboard.model';
import { Listerform } from 'app/shared/models/listerform.model';
import { BpBet } from 'app/shared/models/bpBet.model';
import { BpBetService } from 'app/shared/services/bpBet.service';
import { BetriebService } from 'app/shared/services/betrieb.service';
import { ToastService } from 'app/shared/services/toast.service';
import { prodHTTPService } from 'app/shared/services/production.business-logic.service';
import { InterestService } from 'app/shared/services/interest.service';
import { AlleFavoriten } from 'app/shared/models/favorit_model';
import { FavoritService } from 'app/shared/services/favorit_service';
import { StageService } from 'app/shared/services/stage.service';
import { ProdStageModel } from 'app/shared/models/prod-stage.model';
import { NgbModal, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CalendarService } from 'app/shared/services/calendar.service';
import {
  abkoVeraKateDTOList,
  AnbahnungStammdaten,
  AnbahnungTerminModel,
  einstellungKalendarbetrieb,
  kalendareintrag,
  standardkalender
} from 'app/shared/models/anbahnung.model';
import { listStringEnumMembers } from 'app/shared/util/enum-util';

loadCldr(
  require('./de/numbers.json'),
  require('./de/ca-gregorian.json'),
  require('./de/numberingSystems.json'),
  require('./de/timeZoneNames.json'),
  require('./de/weekdata.json')
);

@Component({
  selector: 'app-calendar',
  templateUrl: './calendar.component.html',
  providers: [
    DayService,
    WeekService,
    WorkWeekService,
    MonthService,
    AgendaService,
    ResizeService,
    DragAndDropService,
    InterestService,
    FavoritService,
    CalendarService
  ],
  styleUrls: ['./calendar.component.scss']
})
export class CalendarComponent implements OnInit {
  private instance: Internationalization = new Internationalization();
  public scheduleData: Object[] = [];
  public format: string = 'dd-MMM-yy hh:mm a';
  public selectedDate: Date = new Date(2020, 0, 10);

  public temp: string =
    '<div class="tooltip-wrap">' +
    '<div class="image ${EventType}"></div>' +
    '<div class="content-area"><div class="name">${produktname}</></div>' +
    '${if(City !== null && City !== undefined)}<div class="city">${City}</div>${/if}' +
    '<div class="time">From&nbsp;:&nbsp;${StartTime.toLocaleString()} </div>' +
    '<div class="time">To&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;:&nbsp;${EndTime.toLocaleString()} </div></div></div>';

  public eventSettings: EventSettingsModel = {
    dataSource: <Object[]>extend([], this.scheduleData, null, true),
    enableTooltip: true,
    tooltipTemplate: this.temp,
    fields: {
      subject: { name: 'produktname' },
      startTime: { name: 'datum_von', validation: { required: true } },
      endTime: { name: 'datum_bis', validation: { required: true } }
    }
  };

  public resourceDataSource: Array<any> = [];
  public staticResource = [
    {
      id: 1,
      betriebId: null,
      bezeichnung: 'BETRIEBKALENDER',
      farbe: '#FF0000',
      reihenfolge: 1,
      checked: true
    },
    {
      id: 2,
      betriebId: null,
      bezeichnung: 'ANFRAGE',
      farbe: '#FFFF00',
      reihenfolge: 2,
      checked: true
    },
    {
      id: 3,
      betriebId: null,
      bezeichnung: 'RESERVIERUNG',
      farbe: '#00FF00',
      reihenfolge: 3,
      checked: true
    },
    {
      id: 4,
      betriebId: null,
      bezeichnung: 'BUCHUNG',
      farbe: '#0000FF',
      reihenfolge: 4,
      checked: true
    },
    {
      id: 5,
      betriebId: null,
      bezeichnung: 'STORNO',
      farbe: '#00FFFF',
      reihenfolge: 5,
      checked: true
    }
  ];
  public isSelected: Boolean = true;
  public dayInterval: number = 3;
  public weekInterval: number = 2;
  public monthInterval: number = 2;
  public spielzeit: number = 12;
  @ViewChild('scheduleObj', { static: false }) public scheduleObj: ScheduleComponent;
  public scheduleView: View = 'Week';
  public viewInterval: number = 6;
  public datas: string[] = ['Day', 'Week', 'WorkWeek', 'Month'];
  public currentView: View = 'Month';
  public currentEvent;
  public allowResizing: Boolean = false;
  public agendaDaysCount: number = 365;
  public firstDayOfWeek: number = 1;

  private subscription: Subscription;
  public keyUp = new Subject<any>();
  public keyUpSpiel = new Subject<any>();
  public queryStringForElasticSearch: Array<any> = [];
  public resultFound: Array<any> = [];
  public searchString: string = null;
  public searchStringSpiel: string = null;
  public searchStringSpielMultiModal: string = null;
  public resultLength = null;
  public showResultList: boolean = false;
  public productionResultNotFound: boolean = false;
  public productionVetragespartner = null;
  public productionSelected: boolean = false;
  public productionVetrageCreate = null;
  public prodVetrageGotIt: boolean = false;

  companyObjectForProd: Betrieb = new Betrieb(
    null,
    null,
    null,
    [],
    null,
    [],
    [],
    null,
    null,
    0,
    0,
    null,
    null,
    null,
    null,
    0,
    0,
    0,
    0,
    2,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    false,
    null,
    true,
    null,
    null,
    null,
    null,
    null,
    null,
    [],
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    0,
    null
  );
  testgescheftb = new GescheftbDTO(
    null,
    null,
    null,
    null,
    null,
    null,
    0,
    [new GsbadresseDTOList(Actioncode.unchanged)],
    [new GsbkomunikationDTOList(Actioncode.unchanged)],
    null,
    null,
    null,
    null,
    null,
    null,
    0
  );
  public searchFailedBetForProd: boolean = false;
  account: DashboardModel;
  bp: Bp = new Bp();
  liland;
  listerform: Listerform[] = [];
  aktivBetrieb: BpBet = null;
  aktivBetriebObject: Betrieb = null;
  modalshoworhide: boolean = false;
  public widgets: Array<any> = [];
  public prodcategories: Array<any> = [];
  public prodcategory: { title: string; hexcode: string } = { title: null, hexcode: null };
  public calendarart: { title: string; hexcode: string } = { title: null, hexcode: null };
  public isCollapsed = false;
  public isCollapsed2 = false;
  public isCollapsed3 = false;
  public isCollapsed3MultiAppo = false;
  public isCollapsed4 = false;
  public isCollapsed5 = false;
  public isCollapsed5MutliAppo = false;
  public isCollapsed6 = false;
  selectedValue: string = 'Bitte wählen';
  selectedValueAddMulti: string = 'Bitte wählen';
  selectedId: number = null;
  viewMode: any;
  prodfilter = [];
  setenddate = [];
  anfragefilter = [];
  favoritenfilter = [];
  standkal1filter = [];
  standkal2filter = [];
  standkal3filter = [];
  standkal4filter = [];

  productionGroupFilter = [];
  productionList = [];

  tourneZeitstartDate = null;
  tourneZeitendDate = null;

  tempListAll = [];
  incomingInterestList: Array<any> = [];
  outgoingInterestList: Array<any> = [];

  favoritenList: Array<any> = [];

  aktiveBetSpiel: ProdStageModel[] = [];
  displayAktiveBetSpiel: boolean = false;
  displayProdSearchResult: boolean = false;
  h: any;
  closeResult: string;
  calendarmode: boolean = true;

  title: Array<any> = [];
  hexcode = [];

  filterAppointmentList = [];
  public cancel: boolean = false;
  public addMultipleAppointmentInstance: {
    produktname: string;
    tourneeZeit: Array<{ datum_bis: any; datum_von: any }>;
    ResourceID: number;
    prodcategories: number;
    vertragepartner: string;
    spiels_name: string;
    spiels_id: number;
    beschreibung: string;
  } = {
    produktname: null,
    tourneeZeit: [{ datum_bis: null, datum_von: null }],
    ResourceID: null,
    prodcategories: null,
    vertragepartner: null,
    spiels_name: null,
    spiels_id: null,
    beschreibung: null
  };

  standardKalender = [];

  public eventCreateOwnResourceObject: kalendareintrag = new kalendareintrag(
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    1,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    0,
    null,
    null,
    null,
    null
  );

  public createAnbahn: AnbahnungStammdaten = new AnbahnungStammdaten(
    [],
    0,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    0,
    null,
    null,
    null
  );
  public createAnbahnTermin: AnbahnungTerminModel = new AnbahnungTerminModel(
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    true,
    0,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    null,
    null
  );
  public artIsNotSelected: boolean = false;

  constructor(
    private es: ElasticsearchService,
    private betriebService: BetriebService,
    private principal: AccountService,
    private bpService: BpService,
    private listerformService: RechtformService,
    private landService: LilandService_bp,
    private aktiv_betriebService: BpBetService,
    public toastService: ToastService,
    private prodHttpService: prodHTTPService,
    private interestService: InterestService,
    private favoritService: FavoritService,
    private modalService: NgbModal,
    private spielService: StageService,
    private calendarService: CalendarService
  ) {
    this.subscription = this.keyUp
      .pipe(
        map(event => event.target.value),
        debounceTime(700),
        distinctUntilChanged()
      )
      .subscribe(x => {
        this.searchWithInputField(x, 'prod');
      });

    this.subscription = this.keyUpSpiel
      .pipe(
        map(event => event.target.value),
        debounceTime(700),
        distinctUntilChanged()
      )
      .subscribe(x => {
        this.displayAktiveBetSpiel = false;
        this.searchWithInputField(x, 'spiel');
        console.log('Spiel needs to be search with: ', x);
      });

    this.widgets = [{ id: 1, title: 'Anfrage', hexcode: '#000000' }, { id: 2, title: 'Reservierung', hexcode: '#dddddd' }];

    this.prodcategories = [
      { id: 1, title: 'Schauspiel', hexcode: '#000000', checked: true },
      { id: 2, title: 'Komödie', hexcode: '#dddddd', checked: true }
    ];
  }

  ngOnInit() {
    L10n.load({
      de: {
        schedule: {
          day: 'Tag',
          week: 'Woche',
          workWeek: 'Arbeitswoche',
          month: 'Monat',
          today: 'Heute',
          newEvent: 'Neuer Kalendereintrag',
          saveButton: 'Eintragen',
          cancelButton: 'Abbrechen',
          deleteButton: 'Löschen'
        },
        datetimepicker: {
          placeholder: 'Wählen Sie ein Datum aus',
          today: 'Heute'
        }
      }
    });

    this.calendarService.getStandardKalendar().subscribe((result: any) => {
      result.forEach(value => value.checked = false)
      this.standardKalender = result;
      console.log('aafafa', this.standardKalender);
    });

    this.principal.identity().subscribe(account => {
      this.account = account;
      this.bpService.find().subscribe((bp: Bp) => {
        this.bp = bp;
        this.loadAktivBetrieb(bp.id);
      });
    });

    this.landService.query().subscribe((land: Liland[]) => {
      this.liland = sortSuggestion(land);
    });

    this.listerformService.query().subscribe((rechtforms: rechform[]) => {
      this.listerform = sortSuggestion(rechtforms);
    });

    console.log(' temin from enum: ', listStringEnumMembers(ListeTerminZustand));
  }

  ngOnDestroy(): void {
    this.subscription.unsubscribe();
  }

  loadAktivBetrieb(id) {
    this.aktiv_betriebService
      .query({
        bpsId: id
      })
      .subscribe((response: BpBet[]) => {
        if (response.length != 0) {
          this.aktivBetrieb = response[0];
          this.testgescheftb.betriebsId = this.aktivBetrieb.betriebsId;
          this.betriebService.findCrowd(this.aktivBetrieb.betriebsId).subscribe((betrieb: Betrieb) => {
            this.aktivBetriebObject = betrieb;
          });
          this.getAllCalendarEvent();
          this.getCalendarResource();
          this.getAllGroupData();
          this.getAllInterestList(this.aktivBetrieb.betriebsId);
          this.getAllFavoriten();
        }
      });
  }

  getAllCalendarEvent() {
    this.calendarService.getKalendarEintrage().subscribe((res: kalendareintrag[]) => {
      this.scheduleData = res;
      this.eventSettings = { dataSource: <Object[]>extend([], this.scheduleData, null, true) };
    });
  }

  getCalendarResource() {
    this.calendarService.geteinstellungBetribeskalender().subscribe((res: einstellungKalendarbetrieb[]) => {
      res.forEach((value: any) => {
        value.checked = true;
      });
      this.resourceDataSource = res.concat(this.staticResource);
    });
  }

  getAllGroupData() {
    let object = {
      api_type: 'menu',
      betrieb_id: this.aktivBetrieb.betriebsId,
      produktion_id: null,
      warengruppe_gruppe_id: 2
    };
    this.prodHttpService.getAngebotMenuListForAnge(object).subscribe(mainObject => {
      let temp: Array<any> = mainObject;
      temp.forEach(value => {
        value.produktgruppe_bezeichnung.forEach(item => {
          if (this.productionGroupFilter.filter(value1 => value1.groupName == item).length == 0) {
            let tempObj = { groupName: item, groupItem: [], check: item == 'Archiv' ? false : true };
            tempObj.groupItem.push(value);
            this.productionGroupFilter.push(tempObj);
          } else {
            let index = this.productionGroupFilter.findIndex(value1 => value1.groupName == item);
            this.productionGroupFilter[index].groupItem.push(value);
          }
        });
      });
      let objectSpiel = {
        api_type: 'menu',
        betrieb_id: this.aktivBetrieb.betriebsId,
        produktion_id: null,
        warengruppe_gruppe_id: 0
      };
      this.prodHttpService.getAngebotMenuListForAnge(objectSpiel).subscribe(spielGroup => {
        let temp1: Array<any> = spielGroup;
        temp1.forEach(value => {
          value.produktgruppe_bezeichnung.forEach(item => {
            if (this.productionGroupFilter.filter(value1 => value1.groupName == item).length == 0) {
              let tempObj = { groupName: item, groupItem: [], check: item == 'Archiv' ? false : true };
              tempObj.groupItem.push(value);
              this.productionGroupFilter.push(tempObj);
            } else {
              let index = this.productionGroupFilter.findIndex(value1 => value1.groupName == item);
              this.productionGroupFilter[index].groupItem.push(value);
            }
          });
        });
        let objectSpiel = {
          api_type: 'menu',
          betrieb_id: this.aktivBetrieb.betriebsId,
          produktion_id: null,
          warengruppe_gruppe_id: 1
        };
        this.prodHttpService.getAngebotMenuListForAnge(objectSpiel).subscribe(werkGroup => {
          let temp2: Array<any> = werkGroup;
          temp2.forEach(value => {
            value.produktgruppe_bezeichnung.forEach(item => {
              if (this.productionGroupFilter.filter(value1 => value1.groupName == item).length == 0) {
                let tempObj = { groupName: item, groupItem: [], check: item == 'Archiv' ? false : true };
                tempObj.groupItem.push(value);
                this.productionGroupFilter.push(tempObj);
              } else {
                let index = this.productionGroupFilter.findIndex(value1 => value1.groupName == item);
                this.productionGroupFilter[index].groupItem.push(value);
              }
            });
          });
        });
      });
    });
  }

  getAllInterestList(id) {
    this.interestService.getAllInterest(id).subscribe(
      res => {
        this.tempListAll = res;
      },
      error => {
        console.error(error);
      },
      () => {
        this.tempListAll.forEach(element => {
          if (this.outgoingInterestList.filter(value1 => value1.groupName == element.warengruppe).length == 0) {
            let tempObj = { groupName: element.warengruppe, groupItem: [] };
            tempObj.groupItem.push(element);
            if (element.von_betrieb_id == this.aktivBetrieb.betriebsId) {
              this.outgoingInterestList.push(tempObj);
            }
          } else {
            let index = this.outgoingInterestList.findIndex(value1 => value1.groupName == element.warengruppe);
            this.outgoingInterestList[index].groupItem.push(element);
          }
        });
      }
    );
  }

  getAllFavoriten() {
    this.favoritService.find_alle_favorit(this.bp.id).subscribe((favoriten: AlleFavoriten[]) => {
      if (favoriten.length != 0) {
        favoriten.forEach(element => {
          if (this.favoritenList.filter(value1 => value1.groupName == element.favorit_art).length == 0) {
            let tempObj = { groupName: element.favorit_art, groupItem: [] };
            tempObj.groupItem.push(element);
            this.favoritenList.push(tempObj);
          } else {
            let index = this.favoritenList.findIndex(value1 => value1.groupName == element.favorit_art);
            this.favoritenList[index].groupItem.push(element);
          }
        });
      }
    });
  }

  search(queryString, tp) {
    if (tp == 'prod') {
      this.productionResultNotFound = false;
      this.productionVetragespartner = null;
      this.productionSelected = false;
    }

    this.es.fullTextSearchFilter(tp, '', '', queryString).subscribe(
      response => {
        let res: any = response;
        this.resultLength = res.hits.total;
        if (res.hits.hits.length != 0) {
          res.hits.hits.forEach(item => this.resultFound.push(item));
          this.showResultList = true;
          if (tp == 'prod') {
            this.displayProdSearchResult = true;
          } else if (tp == 'spiel') {
            this.displayProdSearchResult = false;
          }
          console.log('Search result : ', this.resultFound);
        } else {
          this.productionResultNotFound = true;
          console.log('Not Found at elastic: ');
        }
      },
      error => {
        console.error(error);
      }
    );
  }

  searchWithInputField(searchString, tp) {
    let stringList: Array<string> = searchString
      .replace(/["&/(){}[]/gi, '')
      .trim()
      .split(' ');
    if (stringList.length != 0) {
      this.queryStringForElasticSearch = this.queryStringForElasticSearch.filter(item => !item.hasOwnProperty('query_string'));

      for (let string of stringList) {
        if (string != '') {
          let keyWildcard = string + '*';
          let matchobjTemp = { query_string: {} };
          matchobjTemp.query_string['query'] = keyWildcard;
          matchobjTemp.query_string['fields'] = [
            'betriebsname',
            'prodWerkSearchTeilDTO.titel',
            'beschreibung',
            'titel',
            'vorname',
            'nachname',
            'interne_bezeichnung_der_produkts'
          ];
          this.queryStringForElasticSearch.push(matchobjTemp);
        }
      }

      if (this.queryStringForElasticSearch.length != 0) {
        this.resultFound = [];
        this.search(this.queryStringForElasticSearch, tp);
      } else {
        this.resultFound = [];
      }
    }
  }

  clearSearchVal(event, tp) {
    console.log('selected Production: ', event);
    this.productionSelected = true;
    this.searchString = event.prodWerkSearchTeilDTO.titel;
    this.showResultList = false;
    this.createAnbahn.produktname = event.prodWerkSearchTeilDTO.titel;
    this.createAnbahn.prodProdsId = event.id;
    this.createAnbahn.anbieter_BetriebId = event.betriebsId;
    if (tp == 'main') {
      this.productionVetragespartner = event.angeProdSearchDTO.betriebsname;
    } else if (tp == 'multi') {
      this.addMultipleAppointmentInstance.produktname = event.prodWerkSearchTeilDTO.titel;
      this.addMultipleAppointmentInstance.vertragepartner = event.angeProdSearchDTO.betriebsname;
    }
  }

  selectedItemBetrieb(something: any) {
    //elastic code
    console.log('Bet selected: ', something);
    this.companyObjectForProd.betriebsname = something.betriebsname;
    this.productionVetragespartner = something.betriebsname;
    this.prodVetrageGotIt = true;
  }

  hideResultBox(val) {
    this.prodVetrageGotIt = false;
    this.searchFailedBetForProd = false;
    this.companyObjectForProd.betriebsname = null;
  }

  resultnotFound(event) {
    console.log('not found at prod string: ', event.searchString);
    this.searchFailedBetForProd = true;
    this.companyObjectForProd.betriebsname = event.searchString;
    this.productionVetragespartner = event.searchString;
  }

  talkBack(e?: any) {
    this.productionVetrageCreate = e;
    this.prodVetrageGotIt = true;
    this.showSuccess({
      title: 'Einladung gesendet',
      msg: 'Eine Einladungs-E-Mail wurde an die angegebene Adresse gesendet.',
      timeout: 5000
    });
  }

  closeModalForAngeAfterCreate(i: boolean) {
    console.log('hide modal: ', i);
    if (i) {
      this.modalshoworhide = true;
    } else {
      this.modalshoworhide = false;
    }
  }

  showSuccess(options: any) {
    this.toastService.show(options.msg, {
      classname: 'bg-success',
      delay: options.timeout,
      autohide: true,
      headertext: options.title
    });
  }

  oneventRendered(args: EventRenderedArgs): void {
    const eventColor: string = args.data.EventColor as string;
    if (!args.element || !eventColor) {
      return;
    } else {
      args.element.style.backgroundColor = eventColor;
    }
  }

  dateParser(data: string) {
    return new Date(data);
  }

  displayEventEditModeData(data) {
    if (data.id == undefined) {
      this.selectedValue = 'Bitte wählen';
    } else {
      this.searchStringSpiel = data.spiels_name;
      if (data.kalendar_art == 1) {
        this.selectedValue = this.resourceDataSource.filter(value => value.id === data.betBetriebsKalendarId)[0].bezeichnung;
      } else if (data.kalendar_art == 0) {
      }
    }
  }

  onPopupOpen(args: PopupOpenEventArgs): void {
    console.log('on popup open:  ', args);
    let data: any = args.data;
    this.displayEventEditModeData(data);
    if (args.type == 'QuickInfo') {
      let dialogObj = (<any>args.element).ej2_instances[0];
      dialogObj.hide();
      let currentAction: CurrentAction = args.target.classList.contains('e-work-cells') ? 'Add' : 'Save';
      this.scheduleObj.openEditor(args.data, currentAction, true);
      /*if (data.ResourceID == 1 || data.ResourceID == 2) {
        this.searchString = data.Subject;
      }*/
      if (data.kalendar_art === 1) {
        this.selectedValue = this.resourceDataSource.filter(value => value.id == data.betBetriebsKalendarId)[0].bezeichnung;
      }
      this.productionVetragespartner = data.vertragepartner;
    }
  }

  onPopupClose(args: PopupCloseEventArgs) {
    console.log('on popup close reset the data: ', args);
    let temp: any = args.data;
    if (args.type === 'QuickInfo' || args.type === 'Editor') {
      if (args.data != undefined) {
        /*  let tempValidation = this.checkArtOfEvent();
        if (tempValidation == false) {
          args.cancel = true;
        }*/
      }
    }
  }

  getTimeString(value: Date): string {
    return this.instance.formatDate(value, { skeleton: 'hm' });
  }

  checkArtOfEvent() {
    if (this.selectedValue == null || this.selectedValue == 'Bitte wählen') {
      this.artIsNotSelected = true;
      return false;
    } else {
      return true;
    }
  }

  onActionBegin(args: ActionEventArgs): void {
    if (args.requestType === 'eventCreate' || args.requestType === 'eventChange') {
      let data: any;
      if (args.requestType === 'eventCreate') {
        data = <any>args.data[0];
      } else if (args.requestType === 'eventChange') {
        data = <any>args.data;
      }

      if (!this.scheduleObj.isSlotAvailable(data.datum_von as Date, data.datum_bis as Date)) {
        args.cancel = true;
      }
    }
  }

  actionCompleted(args: ActionEventArgs): void {
    console.log('on action completed: ', args);

    if (args.requestType == 'eventCreated') {
      let data: any = args.data;
      console.log(' event data for the :', data);
      if (this.selectedId > 5) {
        this.createOwnResourceEvent(data);
      } else if (this.selectedId <= 5) {
        this.createDefaultResourceEvent(data);
      }
    }
  }

  createDefaultResourceEvent(data) {
    this.createAnbahn.veranstalter_BetriebId = this.aktivBetrieb.betriebsId;
    this.createAnbahn.bpsId = this.bp.id;
    this.createAnbahn.anmerkung = data[0].beschreibung;
    this.calendarService.createAnbahnungStammdaten(this.createAnbahn).subscribe(res => {
      console.log('Anbahnug Created: ', res);
      this.createAnbahnTermin.anbasId = res.id;
      this.createAnbahnTermin.termin_von = data[0].datum_von.toString();
      this.createAnbahnTermin.termin_bis = data[0].datum_bis.toString();
      this.calendarService.createAnbahnungTermin(this.createAnbahnTermin).subscribe(res => {
        console.log('Anbahnug termin created: ', res);
      });
    });
  }

  createOwnResourceEvent(data) {
    this.eventCreateOwnResourceObject.betriebId = this.aktivBetrieb.betriebsId;
    this.eventCreateOwnResourceObject.produktname = data[0].produktname;
    this.eventCreateOwnResourceObject.datum_von = data[0].datum_von.toString();
    this.eventCreateOwnResourceObject.datum_bis = data[0].datum_bis.toString();
    this.eventCreateOwnResourceObject.beschreibung = data[0].beschreibung;
    this.calendarService.createKalendarEintrage(this.eventCreateOwnResourceObject).subscribe((res: kalendareintrag) => {
      this.scheduleData.push(res);
      this.eventSettings = { dataSource: <Object[]>extend([], this.scheduleData, null, true) };
      this.resetVariable();
    });
  }

  createNewResource() {
    let obj: einstellungKalendarbetrieb = new einstellungKalendarbetrieb(
      this.aktivBetrieb.betriebsId,
      this.calendarart.title,
      this.calendarart.hexcode,
      null
    );
    this.calendarService.createeinstellungBetribeskalender(obj).subscribe((res: einstellungKalendarbetrieb) => {
      let temp: any = res;
      temp.checked = true;
      this.resourceDataSource.push(res);
      this.scheduleObj.addResource(temp, 'betBetriebsKalendarId', this.resourceDataSource.length + 1);
      this.scheduleObj.refresh();
      this.calendarart = { title: null, hexcode: null };
      this.isCollapsed = false;
    });
  }

  addProdcategory() {
    const title: string = this.prodcategory.title;
    const hexcode: string = this.prodcategory.hexcode;
    this.prodcategories.push({ title: title, id: this.prodcategories.length + 1, hexcode: hexcode, checked: true });
    this.isCollapsed5 = false;
  }

  getCombinId(id) {
    if (id == 1) {
      return 1;
    } else if (id == 2) {
      return 2;
    } else if (id == 3) {
      return 5;
    } else if (id == 4) {
      return 8;
    } else if (id == 5) {
      return 11;
    }
  }

  selectValue(daten: any) {
    this.selectedValue = daten.bezeichnung;
    this.selectedId = daten.id;
    if (daten.id <= 5) {
      this.createAnbahnTermin.anbieterZustandId = this.getCombinId(daten.id);
      this.createAnbahnTermin.veranstalterZustandId = this.getCombinId(daten.id);
      console.log('create anbahn termin obj:', this.createAnbahnTermin);
    } else {
      this.eventCreateOwnResourceObject.kalendar_art = 1;
      this.eventCreateOwnResourceObject.betBetriebsKalendarId = daten.id;
    }
  }

  selectValueMultiAppintment(daten: any) {
    if (daten.bezeichnung != undefined) {
      this.addMultipleAppointmentInstance.ResourceID = daten.id;
    }
    this.selectedValueAddMulti = daten.bezeichnung;
  }

  appointmentFilltering() {
    let mainData = [];
    this.scheduleData.forEach((value: any) => {
      let resData = this.resourceDataSource.filter(res => res.Id == value.ResourceID);
      let prodKat = this.prodcategories.filter(res => res.id == value.prodcategories);
      if (prodKat.length != 0 && resData.length != 0) {
        if (prodKat[0].checked) {
          if (resData[0].checked) {
            mainData.push(value);
          }
        }
      } else {
        mainData.push(value);
      }
    });
    this.eventSettings = { dataSource: <Object[]>extend([], mainData, null, true) };
  }

  opengroups(i: number, tp) {
    if (tp == 'prod') {
      if (this.prodfilter[i] == true) {
        this.prodfilter[i] = false;
      } else {
        this.prodfilter[i] = true;
      }
    } else if (tp == 'anfrage') {
      if (this.anfragefilter[i] == true) {
        this.anfragefilter[i] = false;
      } else {
        this.anfragefilter[i] = true;
      }
    } else if (tp == 'fav') {
      if (this.favoritenfilter[i] == true) {
        this.favoritenfilter[i] = false;
      } else {
        this.favoritenfilter[i] = true;
      }
    } else if (tp == 'standkal-feiertag') {
      if (this.standkal1filter[i] == true) {
        this.standkal1filter[i] = false;
      } else {
        this.standkal1filter[i] = true;
      }
    } else if (tp == 'standkal-schulferien') {
      if (this.standkal2filter[i] == true) {
        this.standkal2filter[i] = false;
      } else {
        this.standkal2filter[i] = true;
      }
    } else if (tp == 'standkal-events') {
      if (this.standkal3filter[i] == true) {
        this.standkal3filter[i] = false;
      } else {
        this.standkal3filter[i] = true;
      }
    } else if (tp == 'standkal-messe') {
      if (this.standkal4filter[i] == true) {
        this.standkal4filter[i] = false;
      } else {
        this.standkal4filter[i] = true;
      }
    }
  }

  openEndDate(i: number) {
    if (this.setenddate[i] == true) {
      this.setenddate[i] = false;
    } else {
      this.setenddate[i] = true;
    }
  }

  getDateForProduction(prod) {
    console.log('prod value for highlight: ', prod);

    /*if (this.tourneZeitstartDate != null && this.tourneZeitendDate != null) {
      this.tourneZeitendDate = null;
      this.tourneZeitstartDate = null;
    } else {
      this.tourneZeitendDate = new Date(2020, 1, 10);
      this.tourneZeitstartDate = new Date(2020, 1, 1);
    }*/
  }

  getAllStageOfAktiveBet() {
    this.spielService.getAllSpielAktiveBet(this.aktivBetrieb.betriebsId).subscribe((res: ProdStageModel[]) => {
      this.aktiveBetSpiel = res;
    });
  }

  spielSelected(result, tp) {
    console.log('Spiel selected: ', result);
    if (tp == 'myOwn') {
      this.displayAktiveBetSpiel = false;
      this.searchStringSpiel = result.interne_bezeichnung_der_produkts;
      this.createAnbahn.spielssId = result.spielssId;
    } else if (tp == 'elastic') {
      this.displayAktiveBetSpiel = false;
      this.showResultList = false;
      this.searchStringSpiel = result.interne_bezeichnung_der_produkts;
      this.createAnbahn.spielssId = result.spielssId;
    }
    if (this.eventCreateOwnResourceObject.kalendar_art == 1) {
      this.eventCreateOwnResourceObject.spiel_id = result.spielssId;
      this.eventCreateOwnResourceObject.spiels_name = result.interne_bezeichnung_der_produkts;
    } else {
    }
  }

  spielSelectedMultiModal(result, tp) {
    if (tp == 'myOwn') {
      this.displayAktiveBetSpiel = false;
      this.searchStringSpielMultiModal = result.interne_bezeichnung_der_produkts;
      this.addMultipleAppointmentInstance.spiels_name = result.interne_bezeichnung_der_produkts;
      this.addMultipleAppointmentInstance.spiels_id = result.spielssId;
    } else if (tp == 'elastic') {
      this.displayAktiveBetSpiel = false;
      this.showResultList = false;
      this.searchStringSpielMultiModal = result.interne_bezeichnung_der_produkts;
      this.addMultipleAppointmentInstance.spiels_name = result.interne_bezeichnung_der_produkts;
    }
    if (this.eventCreateOwnResourceObject.kalendar_art == 1) {
      this.eventCreateOwnResourceObject.spiel_id = result.spielssId;
      this.eventCreateOwnResourceObject.spiels_name = result.interne_bezeichnung_der_produkts;
    } else {
    }
  }

  open(content) {
    this.modalService.open(content, { ariaLabelledBy: 'modal-basic-title' }).result.then(
      result => {
        this.closeResult = `Closed with: ${result}`;
      },
      reason => {
        this.closeResult = `Dismissed ${this.getDismissReason(reason)}`;
      }
    );
  }

  private getDismissReason(reason: any): string {
    if (reason === ModalDismissReasons.ESC) {
      return 'by pressing ESC';
    } else if (reason === ModalDismissReasons.BACKDROP_CLICK) {
      return 'by clicking on a backdrop';
    } else {
      return `with: ${reason}`;
    }
  }

  public highlightCell(standKalStart: any, standKalEnd: any, tp: string): void {
    console.log('data received: ', standKalEnd.split("-"));
    let tempStr = standKalStart.split("-");
    let tempEnd = standKalEnd.split("-");
    // let srtDate = new Date(+tempStr[0],+tempStr[1],+tempStr[2]);
    // let endDate = new Date(+tempEnd[0],+tempEnd[1],+tempEnd[2]);
    let srtDate = new Date(standKalStart);
    let endDate = new Date(standKalEnd);
    let element = document.querySelectorAll('.e-work-cells');
    for (let i = 0; i < element.length; i++) {
      let data = element[i].getAttribute('data-date');
      if (srtDate.getTime() === endDate.getTime()) {
        console.log("condition check: ", parseInt(data) == srtDate.getTime() && endDate.getTime() == parseInt(data))
        if (parseInt(data) == srtDate.getTime()) {
          console.log('Date is same: ')
          element[i].classList.add('custom');
          element[i].innerHTML = tp;
        }
      } else {
        console.log('Date is Not the same: ')
        if (parseInt(data) >= srtDate.getTime() && endDate.getTime() >= parseInt(data)) {
          console.log('All cell received: ', element[i]);
          element[i].classList.add('custom');
          element[i].innerHTML = tp;
        }
      }

    }
  }

  getStandKalDates(standKal: any) {
    console.log('kalender date: ', standKal);
    // this.scheduleObj.refresh();
    if (standKal.checked) {
      standKal.checked = false;
      this.onRemoveHighlight();
    } else {
      standKal.checked = true;
      standKal.standKaleDetailsDTOList.forEach(value => {
        this.highlightCell(value.datum_von, value.datum_bis, value.bezeichnung);
      });
    }
  }

  public onRemoveHighlight(): void {
    let elementList: NodeListOf<Element> = document.querySelectorAll('.custom');
    removeClass(elementList, 'custom');
    // elementList.forEach(value => value.innerHTML = '')
  }

  changeCalendarmode() {
    this.calendarmode = !this.calendarmode;
  }

  addMoreThanOneAppointment(content) {
    this.modalService.open(content, { ariaLabelledBy: 'modal-basic-title' }).result.then(
      result => {
        this.closeResult = `Closed with: ${result}`;
      },
      reason => {
        this.closeResult = `Dismissed ${this.getDismissReason(reason)}`;
      }
    );
  }

  trackByIndex(i: number) {
    return i;
  }

  addTourneZeit() {
    this.addMultipleAppointmentInstance.tourneeZeit.push({ datum_von: null, datum_bis: null });
  }

  removeToureZeit(i) {
    this.addMultipleAppointmentInstance.tourneeZeit.splice(i);
  }

  addMultipleEventSchedule() {
    console.log('appointment instance: ', this.addMultipleAppointmentInstance);
    let bar = new Promise((resolve, reject) => {
      this.addMultipleAppointmentInstance.tourneeZeit.forEach((value, index, array) => {
        let obj: kalendareintrag = new kalendareintrag(
          null,
          this.addMultipleAppointmentInstance.beschreibung,
          this.addMultipleAppointmentInstance.ResourceID,
          this.aktivBetrieb.betriebsId,
          value.datum_bis,
          value.datum_bis,
          null,
          1,
          null,
          null,
          null,
          this.addMultipleAppointmentInstance.produktname,
          null,
          this.addMultipleAppointmentInstance.spiels_id,
          this.addMultipleAppointmentInstance.spiels_name,
          0,
          null,
          null,
          null,
          null
        );
        this.calendarService.createKalendarEintrage(obj).subscribe((res: kalendareintrag) => {
          this.scheduleData.push(res);
          this.eventSettings = { dataSource: <Object[]>extend([], this.scheduleData, null, true) };
        });
        if (index === array.length - 1) resolve();
        console.log('date value:  ', this.scheduleData);
      });
    });

    bar.then(() => {
      console.log('All done!');
      this.resetVariable();
    });
  }

  resetVariable() {
    this.productionSelected = false;
    this.productionResultNotFound = false;
    this.isCollapsed = false;
    this.isCollapsed5MutliAppo = false;
    this.isCollapsed3MultiAppo = false;
    this.showResultList = false;
    this.displayProdSearchResult = false;
    this.isCollapsed3MultiAppo = false;
    this.displayAktiveBetSpiel = false;
    this.selectedValueAddMulti = 'Bitte wählen';
    this.selectedValue = 'Bitte wählen';
    this.searchString = null;
    this.searchStringSpielMultiModal = null;
    this.searchStringSpiel = null;
    this.resultFound = [];
    this.addMultipleAppointmentInstance = {
      produktname: null,
      tourneeZeit: [{ datum_von: null, datum_bis: null }],
      ResourceID: null,
      prodcategories: null,
      vertragepartner: null,
      spiels_name: null,
      beschreibung: null,
      spiels_id: null
    };
    this.companyObjectForProd = new Betrieb(
      null,
      null,
      null,
      [],
      null,
      [],
      [],
      null,
      null,
      0,
      0,
      null,
      null,
      null,
      null,
      0,
      0,
      0,
      0,
      2,
      null,
      null,
      null,
      null,
      null,
      null,
      null,
      false,
      null,
      true,
      null,
      null,
      null,
      null,
      null,
      null,
      [],
      null,
      null,
      null,
      null,
      null,
      null,
      null,
      null,
      null,
      null,
      null,
      null,
      null,
      null,
      null,
      null,
      null,
      null,
      0,
      null
    );
    this.testgescheftb = new GescheftbDTO(
      null,
      null,
      null,
      null,
      null,
      null,
      0,
      [new GsbadresseDTOList(Actioncode.unchanged)],
      [new GsbkomunikationDTOList(Actioncode.unchanged)],
      null,
      null,
      null,
      null,
      null,
      null,
      0
    );
  }
}
